CpGtools Release history
=========================

Version 1.10.0
-------------

Add :code:`beta_UMAP.py` on 09/24/2021

Version 1.0.8
-------------

Fix bug for :code:`beta_tSNE.py` and :code:`beta_PCA.py` when sample IDs are number. 

Version 1.0.7
-------------

Add :code:`CpG_density_gene_centered.py` on 03/11/2020

Version 1.0.2
-------------

Add :code:`beta_tSNE.py` on 07/15/2019
	This program performs t-SNE (t-Distributed Stochastic Neighbor Embedding) analysis for samples.

Version 1.0.1
-------------


Add :code:`CpG_anno_position.py` on 07/07/2019
	This program annotates CpG by its genomic position using prebuilt or user-provided annotation files.
 
Version 1.0.0
-------------

	Initial release

